pub struct ChunkedIterator<R: Read, const MAX_CHUNK_SIZE: usize> { /* private fields */ }Implementations
Sourceimpl<R: Read, const MAX_CHUNK_SIZE: usize> ChunkedIterator<R, MAX_CHUNK_SIZE>
Lending Iterator. This doesn’t implement Iterator because that doesn’t allow the Item
to borrow from the iterator (so Item couldn’t be &str).
impl<R: Read, const MAX_CHUNK_SIZE: usize> ChunkedIterator<R, MAX_CHUNK_SIZE>
Lending Iterator. This doesn’t implement Iterator because that doesn’t allow the Item to borrow from the iterator (so Item couldn’t be &str).
max_chunk_size: Estimated size of the biggest chunk we will receive. Ideally a power of 2. It’s OK if this is wrong, we will realloc.
pub fn next_chunk(&mut self) -> Option<OrtResult<&str>>