Module http

Module http 

ort: Open Router CLI https://github.com/grahamking/ort

MIT License Copyright (c) 2025 Graham King

Structs

HttpError

Functions

chat_completions
list_models
skip_header
Advances the reader to point to the first line of the body. Returns true if the body has transfer encoding chunked, and hence needs special handling.