pub fn skip_header<T: Read + Write>(
reader: &mut OrtBufReader<TlsStream<T>>,
) -> Result<bool, HttpError>Expand description
Advances the reader to point to the first line of the body. Returns true if the body has transfer encoding chunked, and hence needs special handling.